@@ -127,7 +127,8 @@ class SolanaWallet:
 
 class APIResource:
 
-    __url = "https://api.blockchainapi.com/v1/"
+    # _url = "https://api.blockchainapi.com/v1/"
+    _url = "http://0.0.0.0:8080/v1/"
     __timeout = 120
 
     class _RequestMethod(Enum):
@@ -184,7 +185,7 @@ class APIResource:
         args = {
             'method': request_method.value,
             'headers': headers,
-            'url': self.__url + endpoint,
+            'url': self._url + endpoint,
             'timeout': self.__timeout
         }
         if files is not None:
